#!/bin/bash -e
set -eo pipefail
shopt -s nullglob

SERVICES=${WAIT_SERVICES:=''}
TIMEOUT=${WAIT_TIMEOUT:='15'}

if [[ ! -z $SERVICES ]] ; then
    for service in $SERVICES ; do
        wait-for-it -t $TIMEOUT $service
    done
fi
# usage: file_env VAR [DEFAULT]
#    ie: file_env 'XYZ_DB_PASSWORD' 'example'
# (will allow for "$XYZ_DB_PASSWORD_FILE" to fill in the value of
#  "$XYZ_DB_PASSWORD" from a file, especially for Docker's secrets feature)
file_env() {
	local var="$1"
	local fileVar="${var}_FILE"
	local def="${2:-}"
	if [ "${!var:-}" ] && [ "${!fileVar:-}" ]; then
		echo "Both $var and $fileVar are set (but are exclusive)"
	fi
	local val="$def"
	if [ "${!var:-}" ]; then
		val="${!var}"
	elif [ "${!fileVar:-}" ]; then
		val="$(< "${!fileVar}")"
	fi
	export "$var"="$val"
    echo " the ${var} shall be set to ${val}"
	unset "$fileVar"
}
# Loads various settings that are used elsewhere in the script
# This should be called after mysql_check_config, but before any other functions
docker_setup_env() {

	# Initialize values that might be stored in a file
	file_env 'OS_PASSWORD'

}
docker_setup_env "$@"
eval "/opt/eoxserver/eoxserver-entrypoint.sh $@"
